#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.2/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/build/haskell-tasty-discover/src/tasty-discover-5.0.2/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-discover
version:              5.0.2
visibility:           public
id:                   tasty-discover-5.0.2-Dg2f1GWKjSTH5ErVD08hg
key:                  tasty-discover-5.0.2-Dg2f1GWKjSTH5ErVD08hg
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  dd490f892414de586c1f5814774eddb0
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-discover-5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-discover-5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-discover-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.2-Dg2f1GWKjSTH5ErVD08hg
depends:
    Glob-0.10.2-5NIlnTlaJTc9rYkovyRlLy base-4.18.2.1 containers-0.6.7
    filepath-1.4.300.1 tasty-1.5.2-FiRZ1IWcSZ79yf7Nf1HVSK

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

